document.getElementById("Contents").innerHTML='\
    <ul><li><input type="checkbox" id="07"><label for="07">Macros and Scripting</label><ul>\
    <li><input type="checkbox" id="0701"><label for="0701">General Information and User Interface Usage</label><ul>\
    <li><a target="_top" href="hr/text/sbasic/shared/main0601.html">LibreOffice Basic pomoć</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01000000.html">Programming with LibreOffice Basic</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/00000002.html">LibreOffice Basic rječnik</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01010210.html">Osnove</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01020000.html">Syntax</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01050000.html">LibreOffice Basic IDE</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01030100.html">IDE prikaz</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01030200.html">Osnovni Urednik</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01050100.html">Nadzor Prozor</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/main0211.html">Makro alatna traka</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/05060700.html">Makronaredba</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/vbasupport.html">Support for VBA Macros</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0702"><label for="0702">Command Reference</label><ul>\
    <li><a target="_top" href="hr/text/sbasic/shared/01020300.html">Koristenje pricedura i funkcija</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01020500.html">Libraries, Modules and Dialogs</a></li>\
    <li><input type="checkbox" id="070202"><label for="070202">Functions, Statements, and Operators</label><ul>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010000.html">Zaslonske U/I funkcije</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020000.html">File I/O Functions</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030000.html">Funkcije vremena i datuma</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03050000.html">Funkcije za rukovanje greškama</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03060000.html">Logicka operacija</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03070000.html">Matematički operatori</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080000.html">Brojčane Funkcije</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090000.html">Kontroliranje progrmskih izvršenja</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100000.html">Varijable</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03040000.html">Basic Constants</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03110000.html">Operatori usporedbe</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120000.html">String</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/special_vba_func.html">Exclusive VBA functions</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03130000.html">Other Commands</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070201"><label for="070201">Abecedni popis funkcija, naredbi i operatora</label><ul>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080601.html">Abs Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03060100.html">AND Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03104200.html">Array Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120101.html">Asc Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120111.html">AscW Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080101.html">Atn Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03130100.html">Beep Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010301.html">Blue Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100100.html">CBool Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120105.html">CByte Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100050.html">CCur Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030116.html">CDateFromUnoDateTime Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030115.html">CDateToUnoDateTime Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030114.html">CDateFromUnoTime Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030113.html">CDateToUnoTime Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030112.html">CDateFromUnoDate Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030111.html">CDateToUnoDate Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030108.html">CDateFromIso Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030107.html">CDateToIso Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100300.html">CDate Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100400.html">CDbl Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100060.html">CDec Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100500.html">CInt Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100600.html">CLng Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100900.html">CSng Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03101000.html">CStr Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090401.html">Call Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020401.html">ChDir Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020402.html">ChDrive Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090402.html">Choose Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120102.html">Chr Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120112.html">ChrW Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020101.html">Close Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100700.html">Const Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120313.html">ConvertFromURL Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120312.html">ConvertToURL Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080102.html">Cos Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03132400.html">CreateObject Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131800.html">CreateUnoDialog Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03132000.html">CreateUnoListener Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131600.html">CreateUnoService Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131500.html">CreateUnoStruct Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03132300.html">CreateUnoValue Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020403.html">CurDir Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100070.html">CVar Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03100080.html">CVErr Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030110.html">DateAdd Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030120.html">DateDiff Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030130.html">DatePart Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030101.html">DateSerial Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030102.html">DateValue Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030301.html">Date Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030103.html">Day Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140000.html">DDB Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090403.html">Declare Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03101100.html">DefBool Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03101300.html">DefDate Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03101400.html">DefDbl Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03101500.html">DefInt Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03101600.html">DefLng Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03101700.html">DefObj Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102000.html">DefVar Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03104300.html">DimArray Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102100.html">Dim Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020404.html">Dir Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090201.html">Do...Loop Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090404.html">End Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03130800.html">Environ Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020301.html">Eof Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03104600.html">EqualUnoObjects Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03060200.html">Eqv Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03050100.html">Erl Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03050200.html">Err Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03050300.html">Error Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03050000.html">Funkcije za rukovanje greškama</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090412.html">Exit Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080201.html">Exp Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020405.html">FileAttr Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020406.html">FileCopy Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020407.html">FileDateTime Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020415.html">FileExists Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020408.html">FileLen Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103800.html">FindObject Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103900.html">FindPropertyObject Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080501.html">Fix Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120301.html">Format Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090406.html">Function Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090400.html">Slejdeće izjave</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140001.html">FV Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080300.html">Generiranje Slučajnih Brojeva</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020409.html">GetAttr Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03132500.html">GetDefaultContext Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03132100.html">GetGuiType Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131700.html">GetProcessServiceManager Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131000.html">GetSolarVersion Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03130700.html">GetSystemTicks Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020201.html">Get Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090301.html">GoSub...Return Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090302.html">GoTo Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010302.html">Green Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03104400.html">HasUnoInterfaces Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080801.html">Hex Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030201.html">Hour Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090103.html">IIf Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090101.html">If...Then...Else Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03060300.html">Imp Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120401.html">InStr Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120411.html">InStrRev Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03160000.html">Input Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010201.html">InputBox Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020202.html">Input# Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080502.html">Int Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140002.html">IPmt Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140003.html">IRR Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102200.html">IsArray Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102300.html">IsDate Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102400.html">IsEmpty Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03104000.html">IsMissing function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102600.html">IsNull Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102700.html">IsNumeric Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102800.html">IsObject Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03104500.html">IsUnoStruct Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120315.html">Join Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020410.html">Kill Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102900.html">LBound Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120302.html">LCase Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120304.html">LSet Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120305.html">LTrim Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120303.html">Left Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120402.html">Len Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103100.html">Let Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020203.html">Line Input # Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020302.html">Loc Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020303.html">Lof Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080202.html">Log Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120306.html">Mid Function, Mid Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030202.html">Minute Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140004.html">MIRR Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020411.html">MkDir Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03070600.html">Mod Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030104.html">Month Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03150002.html">MonthName Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010102.html">MsgBox Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010101.html">MsgBox Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020412.html">Name Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03060400.html">Not Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030203.html">Now Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140005.html">NPer Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140006.html">NPV Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080000.html">Brojčane Funkcije</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080802.html">Oct Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03050500.html">On Error GoTo ... Resume Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090303.html">On...GoSub Statement; On...GoTo Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020103.html">Open Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103200.html">Option Base Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103300.html">Option Explicit Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103350.html">Option VBASupport Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03104100.html">Optional (in Function Statement)</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03060500.html">Or Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140007.html">Pmt Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140008.html">PPmt Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140009.html">PV Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010103.html">Print Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103400.html">Public Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020204.html">Put Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010304.html">QBColor Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140010.html">Rate Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010305.html">RGB Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120308.html">RSet Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120309.html">RTrim Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080301.html">Randomize Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03102101.html">ReDim Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03010303.html">Red Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090407.html">Rem Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020104.html">Reset Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120307.html">Right Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020413.html">RmDir Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080302.html">Rnd Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03170000.html">Round Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030204.html">Second Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020304.html">Seek Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020305.html">Seek Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090102.html">Select...Case Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020414.html">SetAttr Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103700.html">Set Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080701.html">Sgn Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03130500.html">Shell Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080103.html">Sin Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140011.html">SLN Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120201.html">Space Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120314.html">Split Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080401.html">Sqr Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080400.html">Izračunavanje korjena</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103500.html">Static Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090408.html">Stop Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120403.html">StrComp Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120103.html">Str Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120412.html">StrReverse Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120202.html">String Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090409.html">Sub Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090410.html">Switch Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03140012.html">SYD Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080104.html">Tan Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030205.html">TimeSerial Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030206.html">TimeValue Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030302.html">Time Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030303.html">Timer Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03080100.html">Trigonometrijske funkcije</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120311.html">Trim Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131300.html">TwipsPerPixelX Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03131400.html">TwipsPerPixelY Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090413.html">Type Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103600.html">TypeName Function; VarType Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03103000.html">UBound Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120310.html">UCase Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03120104.html">Val Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03130600.html">Wait Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030105.html">WeekDay Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03150001.html">WeekdayName Function [VBA]</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090203.html">While...Wend Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03090411.html">With Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03020205.html">Write Statement</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03060600.html">XOR Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03030106.html">Year Function</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03070100.html">"-" Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03070200.html">"*" Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03070300.html">"+" Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070205"><label for="070205">Advanced Basic Libraries</label><ul>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_formwizard.html">FORMWIZARD Library</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_gimmicks.html">GIMMICKS Library</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_schedule.html">SCHEDULE Library</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_script.html">SCRIPTBINDINGLIBRARY Library</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/03/lib_template.html">TEMPLATE Library</a></li>\
			</ul></li>\
                    </ul></li>\
    <li><input type="checkbox" id="0703"><label for="0703">Guides</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/macro_recording.html">Recording a Macro</a></li>\
    <li><a target="_top" href="hr/text/sbasic/guide/control_properties.html">Izmjena svojstava kontrole i uređivača dijaloških okvira</a></li>\
    <li><a target="_top" href="hr/text/sbasic/guide/insert_control.html">Kreiranje kontrola uređivačem dijaloga</a></li>\
    <li><a target="_top" href="hr/text/sbasic/guide/sample_code.html">Programski primjeri za kontrole u uređivaču dijaloških okvira</a></li>\
    <li><a target="_top" href="hr/text/sbasic/guide/show_dialog.html">Otvaranje dijaloškog okvira programskim kodom</a></li>\
    <li><a target="_top" href="hr/text/sbasic/guide/create_dialog.html">Kreiranje osnovnog dijaloško okvira</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01030400.html">Organiyiranje Knjiznica i Modula</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01020100.html">Koristenje varijabli</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01020200.html">Koristenje objekata</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01030300.html">Debugiranje Basic programa</a></li>\
    <li><a target="_top" href="hr/text/sbasic/shared/01040000.html">Makronaredbe pogonjeni događajima</a></li>\
    <li><a target="_top" href="hr/text/sbasic/guide/access2base.html">Access2Base</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="08"><label for="08">Spreadsheets (Calc)</label><ul>\
    <li><input type="checkbox" id="0801"><label for="0801">General Information and User Interface Usage</label><ul>\
    <li><a target="_top" href="hr/text/scalc/main0000.html">Welcome to the LibreOffice Calc Help</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0503.html">LibreOffice Calc Features</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/keyboard.html">Tipka prečca (LibreOffice Calc Dostupnost)</a></li>\
    <li><a target="_top" href="hr/text/scalc/04/01020000.html">Precaci za Spreadsheet-ove</a></li>\
    <li><a target="_top" href="hr/text/scalc/05/02140000.html">Error Codes in LibreOffice Calc</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060112.html">Dodaj-u Programiranje u LibreOffice kalkulatoru</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/main.html">Upute za oristenje LibreOffice  kalkulatora</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0802"><label for="0802">Command and Menu Reference</label><ul>\
    <li><input type="checkbox" id="080201"><label for="080201">Izbornici</label><ul>\
    <li><a target="_top" href="hr/text/scalc/main0100.html">Izbornici</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0101.html">Datoteka</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0102.html">Uređivanje</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0103.html">Pogled</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0104.html">Ubaci</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0105.html">Oblik</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0116.html">Sheet</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0112.html">Podaci</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0106.html">Alati</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0107.html">Prozor</a></li>\
    <li><a target="_top" href="hr/text/shared/main0108.html">Pomoć</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="080202"><label for="080202">Alatne trake</label><ul>\
    <li><a target="_top" href="hr/text/scalc/main0200.html">Alatne trake</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0202.html">Formatting Bar</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0203.html">Drawing Object Properties Bar</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0205.html">Text Formatting Bar</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0206.html">Traka formule</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0208.html">Statusna traka</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0210.html">Print Preview Bar</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0214.html">Image Bar</a></li>\
    <li><a target="_top" href="hr/text/scalc/main0218.html">Tools Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0201.html">Standardna traka</a></li>\
    <li><a target="_top" href="hr/text/shared/main0212.html">Table Data Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0213.html">Form Navigation Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0214.html">Query Design Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0226.html">Form Design Toolbar</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0803"><label for="0803">Vrste funkcija i operatora</label><ul>\
    <li><a target="_top" href="hr/text/scalc/01/04060000.html">Čarobnjak Funkcije</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060100.html">Funkcije po kategoriji</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060107.html">Matricna funkcija</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060120.html">Bit Operation Functions</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060101.html">Funkcije baze podataka</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060102.html">Date & Time Functions</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060103.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060119.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060118.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060104.html">Informacijska funkcija</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060105.html">Logical Functions</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060106.html">Matematicke funkcije</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060108.html">Statistics Functions</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060181.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060182.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060183.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060184.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060185.html">Financijske funkcije prvi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060109.html">Funkcije Proracnuskih tablica</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060110.html">Funkcija teksta</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060111.html">Dodaj-u funkcija</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060115.html">Dodaj u funkcije, Lista Analitičkih funkcija drugi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060116.html">Dodaj u funkcije, Lista Analitičkih funkcija drugi dio</a></li>\
    <li><a target="_top" href="hr/text/scalc/01/04060199.html">Operators in LibreOffice Calc</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/userdefined_function.html">User-Defined Functions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0804"><label for="0804">Učitavanje, spremanje, uvoz i izvoz</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/webquery.html">Inserting External Data in Table (WebQuery)</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/html_doc.html">Spremanje i otvaranje listova u HTMl-u</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/csv_formula.html">Uvoz i izvoz dBASE datoteka</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0805"><label for="0805">Oblikovanje</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/text_rotate.html">Rotirajuci tekst</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/text_wrap.html">Writing Multi-line Text</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/text_numbers.html">Formatiranje brojeva kao teksta</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/super_subscript.html">Tekstni eksponent/indeks</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/row_height.html">Mijenjanje Visine redova i širine stupaca..</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cellstyle_conditional.html">Primjena pogofbenog oblikovanja</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cellstyle_minusvalue.html">Oznacavanje negativnih brojeva</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cellstyle_by_formula.html">Pridruživanje formata formulama</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/integer_leading_zero.html">Unos Broja sa Vodecim Nulama</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/format_table.html">Formatting Spreadsheets</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/format_value.html">Oblikovanje brojeva s Decimalama</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/value_with_name.html">Imenovanje celija</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/table_rotate.html">Rotating Tables (Transposing)</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/rename_table.html">Preimenovanje listova</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/year2000.html">19xx/20xx godina</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/rounding_numbers.html">Using Rounded Off Numbers</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/currency_format.html">Cells in Currency Format</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/autoformat.html">Using AutoFormat for Tables</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/note_insert.html">Inserting and Editing Comments</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/design.html">Izbor tema za listove</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/fraction_enter.html">Entering Fractions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0806"><label for="0806">Filtering and Sorting</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/filters.html">Applying Filters</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/specialfilter.html">Filter: Primjena Naprednih Filtera</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/autofilter.html">Applying AutoFilter</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/sorted_list.html">Applying Sort Lists</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0807"><label for="0807">Ispisivanje</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/print_title_row.html">Ispis redova ili stupaca na svakoj stranici</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/print_landscape.html">Printing Sheets in Landscape Format</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/print_details.html">Printing Sheet Details</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/print_exact.html">Defining Number of Pages for Printing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0808"><label for="0808">Rasponi podataka</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/database_define.html">Defining Database Ranges</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/database_filter.html">Filtriranje raspona ćelija</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/database_sort.html">Sorting Data</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0809"><label for="0809">Pivot Table</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/datapilot.html">Pivot Table</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/datapilot_createtable.html">Creating Pivot Tables</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/datapilot_deletetable.html">Deleting Pivot Tables</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/datapilot_edittable.html">Editing Pivot Tables</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/datapilot_filtertable.html">Filtering Pivot Tables</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/datapilot_tipps.html">Selecting Pivot Table Output Ranges</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/datapilot_updatetable.html">Updating Pivot Tables</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="08091"><label for="08091">Pivot Chart</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/pivotchart_filter.html">Filtering Pivot Charts</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/pivotchart_update.html">Pivot Chart Update</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/pivotchart_delete.html">Deleting Pivot Charts</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="0810"><label for="0810">Scenariji</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/scenario.html">Koristenje Scenarija</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0811"><label for="0811">Reference</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/relativ_absolut_ref.html">Addresses and References, Absolute and Relative</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cellreferences.html">Referencing a Cell in Another Document</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cellreferences_url.html">References to Other Sheets and Referencing URLs</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cellreference_dragdrop.html">Pomicanje polja odvlačenjem i ispuštanjem</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/address_auto.html">Prepoznavanje Imena kao Adresiranje</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0812"><label for="0812">Prikazivanje, odabiranje, kopiranje</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/table_view.html">Izmjena tablicnih pogleda</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/formula_value.html">Displaying Formulas or Values</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/line_fix.html">Freezing Rows or Columns as Headers</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/multi_tables.html">Navigating Through Sheets Tabs</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/edit_multitables.html">Kopiranje na mnogostruke listove</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cellcopy.html">Kopiraj samo vidljive celije</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/mark_cells.html">Kopiranje na mnogostruke listove</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0813"><label for="0813">Formule i računanje</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/formulas.html">Calculating With Formulas</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/formula_copy.html">Kopiranje formula</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/formula_enter.html">Unos formula</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/formula_value.html">Displaying Formulas or Values</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/calculate.html">Izracunavanje u proracunskim tablicama</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/calc_date.html">Racunanje Sa Datumima i Vremenima</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/calc_series.html">Automatically Calculating Series</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/calc_timevalues.html">Calculating Time Differences</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/matrixformula.html">Entering Matrix Formulas</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0814"><label for="0814">Zaštita</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/cell_protect.html">Zastita Celija od Promjena</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/cell_unprotect.html">Unprotecting Cells</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0815"><label for="0815">Razno</label><ul>\
    <li><a target="_top" href="hr/text/scalc/guide/auto_off.html">Deaktiviranje automatskih promjena</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/consolidate.html">Consolidating Data</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/goalseek.html">Primjenjivanje traženja cilja</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/multioperation.html">Primjena visestrukih operatora</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/multitables.html">Kopiranje na mnogostruke listove</a></li>\
    <li><a target="_top" href="hr/text/scalc/guide/validity.html">Validity of Cell Contents</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="05"><label for="05">Grafikoni i dijagrami</label><ul>\
    <li><input type="checkbox" id="0501"><label for="0501">Opće informacije</label><ul>\
    <li><a target="_top" href="hr/text/schart/main0000.html">Grafovi u LibreOffice</a></li>\
    <li><a target="_top" href="hr/text/schart/main0503.html">LibreOffice Chart Features</a></li>\
    <li><a target="_top" href="hr/text/schart/04/01020000.html">Precac do grafikona</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice Installation</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/ms_doctypes.html">Changing the Association of Microsoft Office Document Types</a></li>\
    <li><a target="_top" href="hr/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="10"><label for="10">Česta pitanja</label><ul>\
    <li><input type="checkbox" id="1001"><label for="1001">General Information</label><ul>\
    <li><a target="_top" href="hr/text/shared/main0400.html">Prečice</a></li>\
    <li><a target="_top" href="hr/text/shared/00/00000005.html">General Glossary</a></li>\
    <li><a target="_top" href="hr/text/shared/00/00000002.html">Glossary of Internet Terms</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/accessibility.html">Dostupnost u LibreOffice</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/keyboard.html">Shortcuts (LibreOffice Accessibility)</a></li>\
    <li><a target="_top" href="hr/text/shared/04/01010000.html">Generalna tipka precac u LibreOffice</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/version_number.html">Inačice i forme brojeva</a></li>\
</ul></li>\
    <li><input type="checkbox" id="1002"><label for="1002">LibreOffice i Microsoft Office</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/ms_user.html">Koristenje Micrisift officea i LibreOffice</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/microsoft_terms.html">Koristenje Micrisift officea i LibreOffice</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/ms_import_export_limitations.html">O konvertranju Microsoft office dokumenata</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/ms_doctypes.html">Changing the Association of Microsoft Office Document Types</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1004"><label for="1004">LibreOffice Options</label><ul>\
    <li><a target="_top" href="hr/text/shared/optionen/01000000.html">Odrednice</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010100.html">Korisnički podaci</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010200.html">Općenito</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010300.html">Putanje</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010400.html">Pomagala za pisanje</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010600.html">Općenito</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010700.html">Pisma</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010800.html">Pogled</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01010900.html">Odrednice ispisa</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01012000.html">Application Colors</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01013000.html">Pristupačnost</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/java.html">Advanced</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/expertconfig.html">Expert Configuration</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/persona_firefox.html">Personalization</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/BasicIDE.html">Basic IDE</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/opencl.html">Open CL</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01020000.html">Load/Save options</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01030000.html">Internet options</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01040000.html">Odrednice tekstualnog dokumenta</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01050000.html">HTML odrednice dokumenta</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01060000.html">Odrednice proračunske tablice</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01070000.html">Odrednice prezentacije</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01080000.html">Odrednice crtanja</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01090000.html">Formula</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01110000.html">Chart options</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01130100.html">VBA svojstva</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01130200.html">Microsoft Office</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01140000.html">Jezici</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01150000.html">Opcije Postavljanja Jezika</a></li>\
    <li><a target="_top" href="hr/text/shared/optionen/01160000.html">Data sources options</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1005"><label for="1005">Čarobnjaci</label><ul>\
    <li><a target="_top" href="hr/text/shared/autopi/01000000.html">Čarobnjak</a></li>\
    <li><input type="checkbox" id="100501"><label for="100501">Čarobnjak za pisma</label><ul>\
    <li><a target="_top" href="hr/text/shared/autopi/01010000.html">Carobnjak za pisanje</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100502"><label for="100502">Čarobnjak za faks</label><ul>\
    <li><a target="_top" href="hr/text/shared/autopi/01020000.html">Fax čarobnjak</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100504"><label for="100504">Čarobnjak za raspored</label><ul>\
    <li><a target="_top" href="hr/text/shared/autopi/01040000.html">Čarobnjak za dnevni red</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100506"><label for="100506">Čarobnjak za izvoz u HTML</label><ul>\
    <li><a target="_top" href="hr/text/shared/autopi/01110000.html">HTML izvoz</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100510"><label for="100510">Čarobnjak za konvertiranje dokumenta</label><ul>\
    <li><a target="_top" href="hr/text/shared/autopi/01130000.html">Konverter dokumenata</a></li>\
			</ul></li>\
    <li><a target="_top" href="hr/text/shared/autopi/01150000.html">Euro Converter Wizard</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1006"><label for="1006">Konfiguriranje LibreOffice</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/configure_overview.html">Configuring LibreOffice</a></li>\
    <li><a target="_top" href="hr/text/shared/01/packagemanager.html">Upravitelj dodataka</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/flat_icons.html">Izmjena pregleda sličica</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/edit_symbolbar.html">Dodavanje gumbova na Alatnu traku</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/workfolder.html">Promjena vašeg radnog direktorija</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/standard_template.html">Changing Default Templates</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_addressbook.html">Registering an Address Book</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/formfields.html">Umetanje i uredjivanje gumbova</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1007"><label for="1007">Korištenje korisničkog sučelja</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/navigator_setcursor.html">Navigation to Quickly Reach Objects</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/navigator.html">Navigator za Pregled Dokumenta</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/autohide.html">Prikaz, sidrenje i skrivanje prozora</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/navpane_on.html">Showing Navigation Pane of the Help</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/textmode_change.html">Switching Between Insert Mode and Overwrite Mode</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/floating_toolbar.html">Using Toolbars</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="10071"><label for="10071">Digital Signatures</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/digital_signatures.html">O digitalnom potpisu</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/digitalsign_send.html">Primjena digitalnog potpisa</a></li>\
    <li><a target="_top" href="hr/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
    <li><a target="_top" href="hr/text/shared/01/signexistingpdf.html">Signing Existing PDF</a></li>\
    <li><a target="_top" href="hr/text/swriter/01/addsignatureline.html">Adding Signature Line in Text Documents</a></li>\
    <li><a target="_top" href="hr/text/swriter/01/signsignatureline.html">Signing the Signature Line</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="1008"><label for="1008">Ispisivanje, faksiranje, slanje</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/labels_database.html">Ispisivanje Adresne oznake</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/print_blackwhite.html">Crno- bijeli ispis</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/email.html">Sending Documents as E-mail</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/fax.html">Sending Faxes and Configuring LibreOffice for Faxing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1009"><label for="1009">Drag & Drop</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop.html">Dragging and Dropping Within a LibreOffice Document</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/dragdroptext.html">Moving and Copying Text in Documents</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_table.html">Copying Spreadsheet Areas to Text Documents</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_graphic.html">Copying Graphics Between Documents</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_fromgallery.html">Kopiranje grafike iz gačerije</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_beamer.html">Drag-and-Drop sa pogledom Izvor Podataka</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1010"><label for="1010">Kopiraj i zalijepi</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/copy_drawfunctions.html">Copying Drawing Objects Into Other Documents</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_graphic.html">Copying Graphics Between Documents</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_fromgallery.html">Kopiranje grafike iz gačerije</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_table.html">Copying Spreadsheet Areas to Text Documents</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1012"><label for="1012">Grafikoni i dijagrami</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/chart_insert.html">Inserting Charts</a></li>\
    <li><a target="_top" href="hr/text/schart/main0000.html">Grafovi u LibreOffice</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1013"><label for="1013">Load, Save, Import, Export</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/doc_open.html">Otvaranje Dokumenata</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/import_ms.html">Opening documents saved in other formats</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/doc_save.html">Spremanje dokumenta</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/doc_autosave.html">Saving Documents Automatically</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/export_ms.html">Saving Documents in Other Formats</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_dbase2office.html">Uvoz i izvoz podataka u Base</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1014"><label for="1014">Poveznice i reference</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/hyperlink_insert.html">Unosenje hiperveza</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/hyperlink_rel_abs.html">Relativni i apsolutni linkovi</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/hyperlink_edit.html">Unosenje hiperveza</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1015"><label for="1015">Praćenje inačica dokumenta</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/redlining_doccompare.html">Comparing Versions of a Document</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/redlining_docmerge.html">Merging Versions</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/redlining_enter.html">Recording Changes</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/redlining.html">Bilježenje i prikazivanje promjena</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/redlining_accept.html">Prihvacanje i odbijanje izmjena</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/redlining_versions.html">Version Management</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1016"><label for="1016">Oznake i posjetnice</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/labels.html">Creating and Printing Labels and Business Cards</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1018"><label for="1018">Umetanje vanjskih podataka</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/copytable2application.html">Inserting Data From Spreadsheets</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/copytext2application.html">Inserting Data From Text Documents</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/insert_bitmap.html">Inserting, Editing, Saving Bitmaps</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/dragdrop_gallery.html">Kopiranje grafike iz gačerije</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1019"><label for="1019">Automatic Functions</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/autocorr_url.html">Automatsko isključivanje prepoznatog URL-a</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1020"><label for="1020">Traženje i izmjenjivanje</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/data_search2.html">Searching With a Form Filter</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_search.html">Searching Tables and Form Documents</a></li>\
    <li><a target="_top" href="hr/text/shared/01/02100001.html">Popis regularnih izraza</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1021"><label for="1021">Smjernice</label><ul>\
    <li><a target="_top" href="hr/text/shared/guide/linestyles.html">Odredjivanje Krajeva Linija</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/text_color.html">Changing the Color of Text</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/change_title.html">Changing the Title of a Document</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/round_corner.html">Kreiranje oblih uglova</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/background.html">Definiranje pozadinske boje i grafike</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/lineend_define.html">Odredjivanje Krajeva Linija</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/linestyle_define.html">Odredjivanje Krajeva Linija</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/insert_graphic_drawit.html">Uređivanje grafičkih objekata</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/line_intext.html">Drawing Lines in Text</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/aaa_start.html">First Steps</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/gallery_insert.html">Umetni Ovjekti iz galerije</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/space_hyphen.html">Inserting Non-breaking Spaces, Hyphens and Soft Hyphens</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/insert_specialchar.html">Inserting Special Characters</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/tabs.html">Umetanje i Uređivanje tabulatora</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/protection.html">Cuvanje sadrzaja uLibreOffice</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/redlining_protect.html">Protecting Records</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/pageformat_max.html">Izbor maksimalnog prostra za ispis na stranici</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/measurement_units.html">Selecting Measurement Units</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/language_select.html">Selecting the Document Language</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_tabledefine.html">Dizajn tablice</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/numbering_stop.html">Turning off Bullets and Numbering for Individual Paragraphs</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="09"><label for="09">Database Functionality (Base)</label><ul>\
    <li><input type="checkbox" id="0901"><label for="0901">Opće informacije</label><ul>\
    <li><a target="_top" href="hr/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/database_main.html">Database Overview</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_new.html">Creating a New Database</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_tables.html">Rad sa grupama</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_queries.html">Rad sa grupama</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_forms.html">Rad sa grupama</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_reports.html">Pravljenje izvješća</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_register.html">Registering and Deleting a Database</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_im_export.html">Uvoz i izvoz podataka u Base</a></li>\
    <li><a target="_top" href="hr/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="04"><label for="04">Presentations and Drawings (Impress/Draw)</label><ul>\
    <li><input type="checkbox" id="0401"><label for="0401">Opće informacije i korištenje korisničkog sučelja</label><ul>\
    <li><a target="_top" href="hr/text/simpress/main0000.html">Welcome to the LibreOffice Impress Help</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0000.html">Welcome to the LibreOffice Draw Help</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0503.html">LibreOffice Impress Features</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0503.html">LibreOffice Draw Features</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/keyboard.html">Korištenje tipkovničkih kratica u LibreOffice Impressu</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/keyboard.html">Shortcut Keys for Drawing Objects</a></li>\
    <li><a target="_top" href="hr/text/simpress/04/01020000.html">Shortcut Keys for LibreOffice Impress</a></li>\
    <li><a target="_top" href="hr/text/simpress/04/presenter.html">Presenter Console Keyboard Shortcuts</a></li>\
    <li><a target="_top" href="hr/text/sdraw/04/01020000.html">Shortcut Keys for Drawings</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/main.html">Instructions for Using LibreOffice Impress</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/main.html">Upute za koristenje LibreOffice Crtanja</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0402"><label for="0402">Command and Menu Reference</label><ul>\
    <li><input type="checkbox" id="040201"><label for="040201">Prezentacije (LibreOffice Impress)</label><ul>\
    <li><input type="checkbox" id="04020101"><label for="04020101">Izbornici</label><ul>\
    <li><a target="_top" href="hr/text/simpress/main0100.html">Izbornici</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0101.html">Datoteka</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0102.html">Uređivanje</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0103.html">Pogled</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0104.html">Ubaci</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0105.html">Oblik</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0117.html">Slide</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0114.html">Prikaz prezentacije</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0106.html">Alati</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0107.html">Prozor</a></li>\
    <li><a target="_top" href="hr/text/shared/main0108.html">Pomoć</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020102"><label for="04020102">Alatne trake</label><ul>\
    <li><a target="_top" href="hr/text/simpress/main0200.html">Alatne trake</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0202.html">Line and Filling Bar</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0203.html">Text Formatting Bar</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0204.html">Slide View Bar</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0206.html">Statusna traka</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0209.html">Ravnala</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0210.html">Drawing Bar</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0211.html">Traka kontura</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0212.html">Slide Sorter Bar</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0213.html">Traka s odrednicama</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0214.html">Image Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0201.html">Standardna traka</a></li>\
    <li><a target="_top" href="hr/text/shared/main0213.html">Form Navigation Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0226.html">Form Design Toolbar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0227.html">Edit Points Bar</a></li>\
                 </ul></li>\
             </ul></li>\
    <li><input type="checkbox" id="040202"><label for="040202">Crteži (LibreOffice Draw)</label><ul>\
    <li><input type="checkbox" id="04020201"><label for="04020201">Izbornici</label><ul>\
    <li><a target="_top" href="hr/text/sdraw/main0100.html">Izbornici</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0101.html">Datoteka</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0102.html">Uređivanje</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0103.html">Pogled</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0104.html">Ubaci</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0105.html">Oblik</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0106.html">Alati</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0113.html">Izmijeni</a></li>\
    <li><a target="_top" href="hr/text/simpress/main0107.html">Prozor</a></li>\
    <li><a target="_top" href="hr/text/shared/main0108.html">Pomoć</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020202"><label for="04020202">Alatne trake</label><ul>\
    <li><a target="_top" href="hr/text/sdraw/main0200.html">Alatne trake</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0210.html">Drawing Bar</a></li>\
    <li><a target="_top" href="hr/text/sdraw/main0213.html">Traka s odrednicama</a></li>\
    <li><a target="_top" href="hr/text/shared/main0201.html">Standardna traka</a></li>\
    <li><a target="_top" href="hr/text/shared/main0213.html">Form Navigation Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0226.html">Form Design Toolbar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0227.html">Edit Points Bar</a></li>\
                 </ul></li>\
             </ul></li>\
         </ul></li>\
    <li><input type="checkbox" id="0403"><label for="0403">Učitavanje, spremanje, uvoz i izvoz</label><ul>\
    <li><a target="_top" href="hr/text/simpress/guide/html_export.html">Saving a Presentation in HTML Format</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/html_import.html">Uvoyenje HTML Stranica u Prezentacije</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/palette_files.html">Loading Color, Gradient, and Hatching Lists</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/animated_gif_save.html">Izvoy Animacija u GIF Formatu</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/table_insert.html">Including Spreadsheets in Slides</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/graphic_insert.html">Inserting Graphics</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/page_copy.html">Kopiranje Slajdova Iz Drugih Prezentacija</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0404"><label for="0404">Oblikovanje</label><ul>\
    <li><a target="_top" href="hr/text/simpress/guide/palette_files.html">Loading Color, Gradient, and Hatching Lists</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/line_arrow_styles.html">Ucitavam Stilove Linija i Strelica</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/color_define.html">Definiranje korisnickih boja</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/gradient.html">Creating Gradient Fills</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/eyedropper.html">Zamjena boje</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/align_arrange.html">Arranging, Aligning and Distributing Objects</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/background.html">Changing the Slide Background Fill</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/footer.html">Adding a Header or a Footer to All Slides</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/masterpage.html">Applying a Slide Design to a Master Slide</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/move_object.html">Pomicanje Objekata</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0405"><label for="0405">Ispisivanje</label><ul>\
    <li><a target="_top" href="hr/text/simpress/guide/printing.html">Printing Presentations</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/print_tofit.html">Printing a Slide to Fit a Paper Size</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0406"><label for="0406">Efekti</label><ul>\
    <li><a target="_top" href="hr/text/simpress/guide/animated_gif_save.html">Izvoy Animacija u GIF Formatu</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/animated_objects.html">Animiranje objekata u Prezentaciji</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/animated_slidechange.html">Animating Slide Transitions</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/cross_fading.html">Cross-Fading Two Objects</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/animated_gif_create.html">Creating Animated GIF Images</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0407"><label for="0407">Objekti, grafika i bitmape</label><ul>\
    <li><a target="_top" href="hr/text/sdraw/guide/combine_etc.html">Combining Objects and Constructing Shapes</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/draw_sector.html">Crtanje Sektora i Segmenata</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/duplicate_object.html">Umnožavanje objekata</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/rotate_object.html">Rotating Objects</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/join_objects3d.html">Assembling 3D Objects</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/join_objects.html">Konekcijske linije</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/text2curve.html">Converting Text Characters into Drawing Objects</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/vectorize.html">Converting Bitmap Images into Vector Graphics</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/3d_create.html">Converting 2D Objects to Curves, Polygons, and 3D Objects</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/line_arrow_styles.html">Ucitavam Stilove Linija i Strelica</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/line_draw.html">Crtanje krivulja</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/line_edit.html">Editing Curves</a></li>\
    <li><a target="_top" href="hr/text/sdraw/guide/graphic_insert.html">Inserting Graphics</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/table_insert.html">Including Spreadsheets in Slides</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/move_object.html">Pomicanje Objekata</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/select_object.html">Selecting Underlying Objects</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/orgchart.html">Kreiraj blok dijagram</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0408"><label for="0408">Groups and Layers</label><ul>\
    <li><a target="_top" href="hr/text/sdraw/guide/groups.html">Grupiranje objekata</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/layers.html">About Layers</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/layer_new.html">Umetanje Slojeva</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/layer_tipps.html">Working With Layers</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/layer_move.html">Moving Objects to a Different Layer</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0409"><label for="0409">Tekst u prezentacijama i slikama</label><ul>\
    <li><a target="_top" href="hr/text/sdraw/guide/text_enter.html">Adding Text</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/text2curve.html">Converting Text Characters into Drawing Objects</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0410"><label for="0410">Prikazivanje</label><ul>\
    <li><a target="_top" href="hr/text/simpress/guide/arrange_slides.html">Promjena redosljeda dijapozitiva</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/change_scale.html">Zooming With the Keypad</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0411"><label for="0411">Slide Shows</label><ul>\
    <li><a target="_top" href="hr/text/simpress/guide/show.html">Prikaz slideshowa</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/presenter_console.html">Using the Presenter Console</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/impress_remote.html">Impress Remote Guide</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/individual.html">Stvaranje Vlastitog Niza Slika</a></li>\
    <li><a target="_top" href="hr/text/simpress/guide/rehearse_timings.html">Ponovi</a></li>\
         </ul></li>\
     </ul></li></ul>\
    <ul><li><input type="checkbox" id="03"><label for="03">Formulas (Math)</label><ul>\
    <li><input type="checkbox" id="0301"><label for="0301">Opće informacije i korištenje korisničkog sučelja</label><ul>\
    <li><a target="_top" href="hr/text/smath/main0000.html">Welcome to the LibreOffice Math Help</a></li>\
    <li><a target="_top" href="hr/text/smath/main0503.html">LibreOffice Math Features</a></li>\
    <li><a target="_top" href="hr/text/smath/guide/main.html">Upute za koristenje LibreOffice Math</a></li>\
    <li><a target="_top" href="hr/text/smath/guide/keyboard.html">Precac(LibreOffice Math Dostupnost)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0302"><label for="0302">Command and Menu Reference</label><ul>\
    <li><a target="_top" href="hr/text/smath/main0100.html">Izbornici</a></li>\
    <li><a target="_top" href="hr/text/smath/main0200.html">Alatne trake</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0303"><label for="0303">Korištenje formula</label><ul>\
    <li><a target="_top" href="hr/text/smath/guide/align.html">Manually Aligning Formula Parts</a></li>\
    <li><a target="_top" href="hr/text/smath/guide/attributes.html">Izmjena Predefiniranih atributa</a></li>\
    <li><a target="_top" href="hr/text/smath/guide/brackets.html">Merging Formula Parts in Brackets</a></li>\
    <li><a target="_top" href="hr/text/smath/guide/comment.html">Entering Comments</a></li>\
    <li><a target="_top" href="hr/text/smath/guide/newline.html">Entering Line Breaks</a></li>\
    <li><a target="_top" href="hr/text/smath/guide/parentheses.html">Inserting Brackets</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="02"><label for="02">Text Documents (Writer)</label><ul>\
    <li><input type="checkbox" id="0201"><label for="0201">Opće informacije i korištenje korisničkog sučelja</label><ul>\
    <li><a target="_top" href="hr/text/swriter/main0000.html">Dobrodošli u Pomoć LibreOffice Writera</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0503.html">Svojstva LibreOffice Writer-a</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/main.html">Instructions for Using LibreOffice Writer</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/resize_navigator.html">Sidrenje i mjenjanje veličine prozora</a></li>\
    <li><a target="_top" href="hr/text/swriter/04/01020000.html">Tipka prečca za LibreOffice pisca</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/words_count.html">Brojanje riječi</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/keyboard.html">Using Shortcut Keys (LibreOffice Writer Accessibility)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0202"><label for="0202">Command and Menu Reference</label><ul>\
    <li><input type="checkbox" id="020201"><label for="020201">Izbornici</label><ul>\
    <li><a target="_top" href="hr/text/swriter/main0100.html">Izbornici</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0101.html">Datoteka</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0102.html">Uređivanje</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0103.html">Pogled</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0104.html">Ubaci</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0105.html">Oblik</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0115.html">Styles</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0110.html">Tablica</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0120.html">Form Menu</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0106.html">Alati</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0107.html">Prozor</a></li>\
    <li><a target="_top" href="hr/text/shared/main0108.html">Pomoć</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="020202"><label for="020202">Alatne trake</label><ul>\
    <li><a target="_top" href="hr/text/swriter/main0200.html">Alatne trake</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0202.html">Traka oblikovanja</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0203.html">Image Bar</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0204.html">Table Bar</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0205.html">Drawing Object Properties Bar</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0206.html">Bullets and Numbering Bar</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0208.html">Statusna traka</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0210.html">Print Preview</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0213.html">Ravnala</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0214.html">Traka formule</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0215.html">Frame Bar</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0216.html">OLE-Object Bar</a></li>\
    <li><a target="_top" href="hr/text/swriter/main0220.html">Traka objekta teksta</a></li>\
    <li><a target="_top" href="hr/text/shared/main0201.html">Standardna traka</a></li>\
    <li><a target="_top" href="hr/text/shared/main0212.html">Table Data Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0213.html">Form Navigation Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0214.html">Query Design Bar</a></li>\
    <li><a target="_top" href="hr/text/shared/main0226.html">Form Design Toolbar</a></li>\
    <li><a target="_top" href="hr/text/swriter/librelogo/LibreLogo.html">LibreLogo Toolbar</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0203"><label for="0203">Stvaranje tekstualnog dokumenta</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/text_nav_keyb.html">Navigating and Selecting With the Keyboard</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/text_direct_cursor.html">Using the Direct Cursor</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0204"><label for="0204">Graphics in Text Documents</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_graphic.html">Inserting Graphics</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_graphic_dialog.html">Inserting a Graphic From a File</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_graphic_gallery.html">Unos grafika iz galerije metodom povuci i ispusti</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_graphic_scan.html">Inserting a Scanned Image</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_graphic_fromchart.html">Inserting a Calc Chart into a Text Document</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_graphic_fromdraw.html">Inserting Graphics From LibreOffice Draw or Impress</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0205"><label for="0205">Tables in Text Documents</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/number_date_conv.html">Turning Number Recognition On or Off in Tables</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/tablemode.html">Modifying Rows and Columns by Keyboard</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/table_delete.html">Brisanje tablica ili sadržaja tablice</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/table_insert.html">Inserting Tables</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/table_repeat_multiple_headers.html">Repeating a Table Header on a New Page</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/table_sizing.html">Promjena veličine redaka i stupaca u tablici s tekstom</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/table_cells.html">Adding or Deleting a Row or Column to a Table Using the Keyboard</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0206"><label for="0206">Objects in Text Documents</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/anchor_object.html">Smjestanje objekata</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/wrap.html">Omatanje teksta oko objekta</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0207"><label for="0207">Sections and Frames in Text Documents</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/sections.html">Korištenje odjeljaka</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/text_frame.html">Umetanje, uređivanje i povezianje tekstulanih okvira</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/section_edit.html">Uređivanje odjeljaka</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/section_insert.html">Umetanje odjeljaka</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0208"><label for="0208">Tables of Contents and Indexes</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/chapter_numbering.html">Chapter Numbering</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_userdef.html">User-Defined Indexes</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_toc.html">Stvaranje tablice sadržaja</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_index.html">Creating Alphabetical Indexes</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_multidoc.html">Indexes Covering Several Documents</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_literature.html">Stvaranje bibliografije</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_delete.html">Editing or Deleting Index and Table Entries</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_edit.html">Ažuriranje, uređivanje i brisanje indeksa i tablica sadržaja</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_enter.html">Određivanje unosa indeksa ili tablice sadržaja</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/indices_form.html">Formatting an Index or a Table of Contents</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0209"><label for="0209">Fields in Text Documents</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/fields.html">O poljima</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/fields_date.html">Inserting a Fixed or Variable Date Field</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/field_convert.html">Converting a Field into Text</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0210"><label for="0210">Navigating Text Documents</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/dragdroptext.html">Moving and Copying Text in Documents</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/arrange_chapters.html">Preuređivanje dokumenta koristeći Navigator</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/hyperlinks.html">Inserting Hyperlinks With the Navigator</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/navigator.html">Navigator for Text Documents</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0211"><label for="0211">Izračunavanje u tekstualnom dokumentu</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/calculate_multitable.html">Calculating Across Tables</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/calculate.html">Izračunavanje u tekstualnom dokumentu</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/calculate_clipboard.html">Izračunavanje i umetanje rezultata formule u tekstualni dokument</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/calculate_intable.html">Calculating Cell Totals in Tables</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/calculate_intext.html">Izračunavanje kompleksnih formula u tekstualnom dokumentu</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/calculate_intext2.html">Displaying the Result of a Table Calculation in a Different Table</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0212"><label for="0212">Formatting Text Documents</label><ul>\
    <li><input type="checkbox" id="021201"><label for="021201">Predlošci i stilovi</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/templates_styles.html">Templates and Styles</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/even_odd_sdw.html">Alternating Page Styles on Odd and Even Pages</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/change_header.html">Creating a Page Style Based on the Current Page</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/load_styles.html">Korištenje stilova iz drugog dokumenta ili predloška</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/stylist_fromselect.html">Creating New Styles From Selections</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/stylist_update.html">Updating Styles From Selections</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/template_create.html">Stvaranje predloška dokumenta</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/template_default.html">Changing the Default Template</a></li>\
			</ul></li>\
    <li><a target="_top" href="hr/text/swriter/guide/pageorientation.html">Changing Page Orientation (Landscape or Portrait)</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/text_capital.html">Changing the Case of Text</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/hidden_text.html">Skriveni tekst</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/header_pagestyles.html">Defining Different Headers and Footers</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/header_with_chapter.html">Inserting a Chapter Name and Number in a Header or a Footer</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/shortcut_writing.html">Primjena oblikovanja teksta tijekom pisanja</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/reset_format.html">Vraćanje početnih atributa fonta</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/stylist_fillformat.html">Primjenjivanje stilova u načinu rada Ispuni oblikovanjem</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/wrap.html">Omatanje teksta oko objekta</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/text_centervert.html">Using a Frame to Center Text on a Page</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/text_emphasize.html">Emphasizing Text</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/text_rotate.html">Rotiranje teksta</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/page_break.html">Inserting and Deleting Page Breaks</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/pagestyles.html">Creating and Applying Page Styles</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/subscript.html">Making Text Superscript or Subscript</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0213"><label for="0213">Special Text Elements</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/captions.html">Korištenje opisa</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/conditional_text.html">Conditional Text</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/conditional_text2.html">Conditional Text for Page Counts</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/fields_date.html">Inserting a Fixed or Variable Date Field</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/fields_enter.html">Adding Input Fields</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/footer_nextpage.html">Umetanje broja sljedeće ili prethodne stranice</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/footer_pagenumber.html">Inserting Page Numbers in Footers</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/hidden_text.html">Skriveni tekst</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/header_pagestyles.html">Defining Different Headers and Footers</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/header_with_chapter.html">Inserting a Chapter Name and Number in a Header or a Footer</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/fields_userdata.html">Querying User Data in Fields or Conditions</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/footnote_usage.html">Umetanje i uređivanje fusnota i završnih bilješki</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/footnote_with_line.html">Razmak između fusnota</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/header_footer.html">About Headers and Footers</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/header_with_line.html">Formatting Headers or Footers</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/text_animation.html">Animiranje teksta</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/form_letters_main.html">Creating a Form Letter</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0214"><label for="0214">Automatic Functions</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/autocorr_except.html">Dodavanje iznimaka na listu automatskog ispravljanja</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/autotext.html">Korištenje automatskog teksta</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/auto_numbering.html">Stvaranje numeriranih, ili listi s grafičkim oznakama</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/auto_off.html">Onemogućavanje automatskog ispravljanja</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/auto_spellcheck.html">Automatska provjera pravopisa</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/number_date_conv.html">Turning Number Recognition On or Off in Tables</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/using_hyphen.html">Rastavljanje riječi</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0215"><label for="0215">Numbering and Lists</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/captions_numbers.html">Dodavanje broja naslova opisu</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/auto_numbering.html">Stvaranje numeriranih, ili listi s grafičkim oznakama</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/chapter_numbering.html">Chapter Numbering</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_tab_innumbering.html">Mijenjanje konturne razine numeriranih i grafičkih lista</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/join_numbered_lists.html">Combining Numbered Lists</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/numbering_lines.html">Dodavanje brojeva retcima</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/numbering_paras.html">Uređivanje brojeva u numeriranoj listi</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/number_sequence.html">Određivanje brojevnog raspona</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/using_numbered_lists2.html">Dodavanje numeriranih lista</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/using_numbering.html">Numbering and Numbering Styles</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/using_numbered_lists.html">Adding Bullets</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0216"><label for="0216">Provjera pravopisa, rječnik sinonima i jezici</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/auto_spellcheck.html">Automatska provjera pravopisa</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/delete_from_dict.html">Uklanjanje riječi iz korisnički definiranog rječnika</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/using_thesaurus.html">Rječnik sinonima</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/spellcheck_dialog.html">Checking Spelling and Grammar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0218"><label for="0218">Savjeti za otklanjanje grešaka</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/insert_beforetable.html">Unos teksta prije tablice na početak stranice</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/jump2statusbar.html">Pozicioniranje na određenu zabilješku</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0219"><label for="0219">Učitavanje, spremanje, uvoz i izvoz</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/send2html.html">Spremanje teksta u HTML formatu</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/textdoc_inframe.html">Inserting an Entire Text Document</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0220"><label for="0220">Glavni dokumenti</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/globaldoc.html">Glavni dokumenti i poddokumenti</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0221"><label for="0221">Poveznice i reference</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/references.html">Umetanje unakrsnih referenci</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/hyperlinks.html">Inserting Hyperlinks With the Navigator</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0222"><label for="0222">Ispisivanje</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/printer_tray.html">Selecting printer paper trays</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/print_preview.html">Previewing a Page Before Printing</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/print_small.html">Ispisivanje više stranica na jednom radnom listu</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/pagestyles.html">Creating and Applying Page Styles</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0223"><label for="0223">Pretraživanje i izmjenjivanje</label><ul>\
    <li><a target="_top" href="hr/text/swriter/guide/search_regexp.html">Using Wildcards in Text Searches</a></li>\
    <li><a target="_top" href="hr/text/shared/01/02100001.html">Popis regularnih izraza</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="06"><label for="06">HTML Documents (Writer Web)</label><ul>\
    <li><a target="_top" href="hr/text/shared/07/09000000.html">Web-stranice</a></li>\
    <li><a target="_top" href="hr/text/shared/02/01170700.html">HTML Filters and Forms</a></li>\
    <li><a target="_top" href="hr/text/swriter/guide/send2html.html">Spremanje teksta u HTML formatu</a></li>\
	</ul></li></ul>\
';
